@@ -1,7 +1,6 @@
 from django.test import SimpleTestCase
 
 import django_weasyprint.tests  # noqa
-from django_weasyprint.views import CONTENT_TYPE_PDF, CONTENT_TYPE_PNG
 
 
 class WeasyTemplateViewTestCase(SimpleTestCase):
@@ -13,12 +12,12 @@ class WeasyTemplateViewTestCase(SimpleTestCase):
         self.assertEqual(response['content-type'], 'text/html; charset=utf-8')
         self.assertEqual(response.content, b'<h1>Example template</h1>\n')
 
-    def test_get_pdf(self):
-        response = self.client.get('/pdf/')
+    def test_get_pdf_download(self):
+        response = self.client.get('/pdf/download/')
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(response.has_header('content-type'))
-        self.assertEqual(response['content-type'], CONTENT_TYPE_PDF)
+        self.assertEqual(response['content-type'], 'application/pdf')
         self.assertTrue(response.has_header('content-disposition'))
         self.assertEqual(
             response['content-disposition'],
@@ -26,10 +25,11 @@ class WeasyTemplateViewTestCase(SimpleTestCase):
         )
         self.assertEqual(response.content[:4], b'%PDF')
 
-    def test_get_png(self):
-        response = self.client.get('/png/')
+    def test_get_pdf(self):
+        response = self.client.get('/pdf/')
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(response.has_header('content-type'))
-        self.assertEqual(response['content-type'], CONTENT_TYPE_PNG)
-        self.assertEqual(response.content[1:4], b'PNG')
+        self.assertEqual(response['content-type'], 'application/pdf')
+        self.assertFalse(response.has_header('content-disposition'))
+        self.assertEqual(response.content[:4], b'%PDF')
